<form
    class="{{ class|default:'m-4 flex flex-col gap-4 rounded bg-gray-400 p-8' }}"
    action="{% url 'login' %}"
    method="post"
>
    {{ form.non_field_errors }}
    {{ form.errors }}
    {% csrf_token %}
    {{ form.username }}
    {{ form.password }}
    <input value="Login" type="submit" class="block w-full cursor-pointer rounded border-2 border-blue-600 bg-blue-500 p-2 text-gray-800 hover:bg-blue-200">
    <input class="hidden" type="hidden" id="next" value="{{ next }}">
</form>
