<form method="post" class="{{ class|default:'flex flex-inline gap-2 rounded-xl border-4 border-gray-600/80 bg-gray-300 p-2' }}" action="{% url 'logout' %}">
    {% csrf_token %}
    {{ form }}
    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="size-6">
        <path stroke-linecap="round" stroke-linejoin="round" d="M8.25 9V5.25A2.25 2.25 0 0 1 10.5 3h6a2.25 2.25 0 0 1 2.25 2.25v13.5A2.25 2.25 0 0 1 16.5 21h-6a2.25 2.25 0 0 1-2.25-2.25V15m-3 0-3-3m0 0 3-3m-3 3H15" />
    </svg>
    <input class="cursor-pointer" value="Logout" type="submit">
</form>
