from django.apps import AppConfig


class CrimsonslatePortfolioConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "crimsonslate_portfolio"
    verbose_name = "Crimsonslate Portfolio Django Application"
