{% extends "portfolio/layout.html" %}
{% block content %}
<div class="flex flex-col items-center gap-4 bg-gray-300 p-8">
    <h2 class="text-2xl text-center">{{ title }}</h2>
    {% include "portfolio/partials/_login.html" %}
</div>
{% endblock content %}
